@@ -467,7 +467,7 @@ const FieldTypes* ConnectionPool::get_field_types() const
   return m_pFieldTypes;
 }
 
-Glib::ustring ConnectionPool::get_string_find_operator() const
+Gnome::Gda::SqlOperatorType ConnectionPool::get_string_find_operator() const
 {
   g_assert(m_backend.get());
   return m_backend->get_string_find_operator();
@@ -532,7 +532,7 @@ bool ConnectionPool::handle_error_cerr_only()
             error_details += '\n'; //Add newline after each error.
 
           error_details += (*iter)->get_description();
-          std::cerr << "Internal error (Database): " << error_details << std::endl;
+          std::cerr << G_STRFUNC << ": Internal error (Database): " << error_details << std::endl;
         }
       }
 
