@@ -44,12 +44,21 @@ Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject,
   m_radio_navigation_none(0),
   m_radio_navigation_specify(0),
   m_label_navigation_automatic(0),
-  m_combo_navigation_specify(0)
-{
+  m_combo_navigation_specify(0),
+  m_spinbutton_row_line_width(0),
+  m_spinbutton_column_line_width(0),
+  m_colorbutton_line(0)
+{  
   // Show the appropriate alternate widgets:
   m_box_table_widgets->hide();
   m_box_related_table_widgets->show();
   m_box_related_navigation->show();
+  m_hbox_rows_count->show();
+  
+  m_spinbutton_rows_count->set_range(0, 100); //Otherwise only 0 would be allowed.
+  m_spinbutton_rows_count->set_increments(1, 10); //Otherwise the buttons do nothing.
+  m_spinbutton_rows_count->signal_value_changed().connect(
+    sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_spinbutton_changed));
 
   builder->get_widget_derived("combo_relationship_name", m_combo_relationship);
   m_combo_relationship->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_combo_relationship_changed));
@@ -70,6 +79,16 @@ Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject,
   make_sensitivity_depend_on_toggle_button(*m_radio_navigation_specify, *m_combo_navigation_specify);
   m_combo_navigation_specify->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_combo_navigation_specific_changed));
 
+  builder->get_widget("spinbutton_row_line_width", m_spinbutton_row_line_width);
+  m_spinbutton_row_line_width->signal_value_changed().connect(
+    sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_spinbutton_changed));
+  builder->get_widget("spinbutton_column_line_width", m_spinbutton_column_line_width);
+  m_spinbutton_column_line_width->signal_value_changed().connect(
+    sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_spinbutton_changed));
+  builder->get_widget("colorbutton_line", m_colorbutton_line);
+  m_colorbutton_line->signal_color_set().connect(
+    sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_spinbutton_changed));
+
 
   m_modified = false;
 
@@ -89,7 +108,7 @@ Dialog_Layout_List_Related::~Dialog_Layout_List_Related()
 }
 
 
-void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const sharedptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table)
+void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const sharedptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table, bool for_print_layout)
 {
   //Ignore the provided from_table if the portal has one:
   Glib::ustring actual_from_table;
@@ -107,11 +126,31 @@ void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout_name,
     m_portal = glom_sharedptr_clone(portal);
   else
     m_portal = sharedptr<LayoutItem_Portal>::create(); //The rest of the class assumes that this is not null.
+    
+  m_spinbutton_rows_count->set_value( m_portal->get_rows_count() );
 
   type_vecConstLayoutFields empty_fields; //Just to satisfy the base class.
   Dialog_Layout::set_document(layout_name, layout_platform, document, actual_from_table, empty_fields);
   //m_table_name is now actually the parent_table_name.
 
+  //Hide unwanted widgets and show extra ones:
+  if(for_print_layout)
+  {
+    m_box_related_navigation->hide();
+    m_box_frame_lines->show();
+    
+    m_spinbutton_row_line_width->set_value(
+      portal->get_print_layout_row_line_width());
+    m_spinbutton_column_line_width->set_value(
+      portal->get_print_layout_column_line_width());
+
+    Gdk::Color color( portal->get_print_layout_line_color() );
+    m_colorbutton_line->set_color(color);
+
+    //Avoid showing formatting options that are about editing:
+    m_editable_layout = false;
+  }
+
   update_ui();
 }
 
@@ -229,22 +268,13 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
   }
 
   //Describe the automatic navigation:
-  sharedptr<const UsesRelationship> relationship_navigation_automatic;
-  bool navigation_automatic_main = false;
-  relationship_navigation_automatic = get_portal_navigation_relationship_automatic(m_portal, navigation_automatic_main);
-  Glib::ustring automatic_navigation_description;
-
-  if(navigation_automatic_main)
-    automatic_navigation_description = m_portal->get_relationship_name_used();
-  else if(relationship_navigation_automatic)
+  sharedptr<const UsesRelationship> relationship_navigation_automatic = 
+    get_portal_navigation_relationship_automatic(m_portal);
+  Glib::ustring automatic_navigation_description = 
+    m_portal->get_relationship_name_used(); //TODO: Use get_relationship_display_name() instead?
+  if(relationship_navigation_automatic) //This is a relationship in the related table.
   {
-    automatic_navigation_description = m_portal->get_relationship_name_used();
-
-    if(relationship_navigation_automatic->get_has_relationship_name())
-      automatic_navigation_description += ("::" + relationship_navigation_automatic->get_relationship_name());
-
-    if(relationship_navigation_automatic->get_has_related_relationship_name())
-      automatic_navigation_description += ("::" + relationship_navigation_automatic->get_related_relationship_name());
+    automatic_navigation_description += ("::" + relationship_navigation_automatic->get_relationship_display_name());
   }
 
   if(automatic_navigation_description.empty())
@@ -264,7 +294,7 @@ void Dialog_Layout_List_Related::save_to_document()
   if(m_modified)
   {
     //Get the data from the TreeView and store it in the document:
-
+    
     //Get the groups and their fields:
     Document::type_list_layout_groups mapGroups;
 
@@ -320,7 +350,16 @@ void Dialog_Layout_List_Related::save_to_document()
       uses_rel->set_related_relationship(sharedptr<Relationship>());
       m_portal->set_navigation_type(LayoutItem_Portal::NAVIGATION_NONE);
     }
-
+    
+    m_portal->set_rows_count( m_spinbutton_rows_count->get_value() );
+    
+   
+    m_portal->set_print_layout_row_line_width(
+      m_spinbutton_row_line_width->get_value());
+    m_portal->set_print_layout_column_line_width(
+      m_spinbutton_column_line_width->get_value());      
+    //TODO: Use GdkRGBA's color string (CSS) format instead, everywhere:
+    m_portal->set_print_layout_line_color( m_colorbutton_line->get_color().to_string() );
   }
 }
 
@@ -400,6 +439,11 @@ void Dialog_Layout_List_Related::on_combo_relationship_changed()
   m_modified = true;
 }
 
+void Dialog_Layout_List_Related::on_spinbutton_changed()
+{
+  m_modified = true;
+}
+
 sharedptr<Relationship> Dialog_Layout_List_Related::get_relationship() const
 {
   std::cout << "debug: I wonder if this function is used." << std::endl;
